@@ -1,6 +1,6 @@
 import zipfile
 
-from src.sqlcarve.validator.executeQuery import *
+from sqlcarve.validator.executeQuery import *
 #from src.sqlcarve.validator.validator import *
 
 def analyse(referencefile, fichier):
